Returned by get_scheme() on any CCParams object. R-side name
SchemeId matches the upstream pke/scheme/scheme-id.h header
filename and avoids colliding with a potential future Scheme S7
class.
Returned by get_scheme() on any CCParams object. R-side name
SchemeId matches the upstream pke/scheme/scheme-id.h header
filename and avoids colliding with a potential future Scheme S7
class.