Generate bootstrapping keys
Value
Invisibly, the cc crypto context that was passed in. Called for
its side effect: the rotation and evaluation keys bootstrapping
needs are generated from sk and stored inside the C++ context,
after which eval_bootstrap() can be called.