Returns omp_get_max_threads(): the maximum number of threads OpenFHE
will use for a parallel region under the current settings (see
set_num_threads()). Returns 1 when the package was built without
OpenMP.
Returns omp_get_max_threads(): the maximum number of threads OpenFHE
will use for a parallel region under the current settings (see
set_num_threads()). Returns 1 when the package was built without
OpenMP.